# Biblioteca do Labican-UFRN

**mlabican** é uma biblioteca Python para **aprendizado semissupervisionado**, focada em algoritmos baseados em **Self-Training** e suas variantes. Ela fornece implementações robustas e reutilizáveis que permitem treinar modelos com poucos dados rotulados, reavaliando pseudo-rótulos de maneira inteligente com uso de silhueta, comitês de classificadores e votação ponderada.

## 📦 Instalação

```bash
pip install mlabican